@@ -2,7 +2,7 @@ from jste_plugins.autocomplete import *
 from jste_plugins.jquery_plugins import *
 from jste_plugins.json_plugins import *
 
-from pyte_plugins.autocomplete import *
+from pyte_plugins.autocomplete.autocomplete import *
 from pyte_plugins.djte_plugins.class_plugins import *
 from pyte_plugins.djte_plugins.text_plugins import *
 from pyte_plugins.text_plugins import *
